@@ -15,15 +15,14 @@
 #include "absl/strings/ascii.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/string_view.h"
-#include "google/protobuf/descriptor.h"
 #include "google/protobuf/compiler/hpb/gen_accessors.h"
 #include "google/protobuf/compiler/hpb/gen_enums.h"
 #include "google/protobuf/compiler/hpb/gen_extensions.h"
 #include "google/protobuf/compiler/hpb/gen_utils.h"
 #include "google/protobuf/compiler/hpb/names.h"
 #include "google/protobuf/compiler/hpb/output.h"
-#include "upb_generator/common.h"
-#include "upb_generator/file_layout.h"
+#include "google/protobuf/descriptor.h"
+#include "upb_generator/minitable/names.h"
 
 namespace google::protobuf::hpb_generator {
 
@@ -101,7 +100,6 @@ void WriteModelAccessDeclaration(const protobuf::Descriptor* descriptor,
               : msg_(const_cast<$1*>(msg)), arena_(arena) {
             assert(arena != nullptr);
           }  // NOLINT
-          void* GetInternalArena() const { return arena_; }
       )cc",
       ClassName(descriptor), MessageName(descriptor));
   WriteFieldAccessorsInHeader(descriptor, output);
@@ -113,7 +111,7 @@ void WriteModelAccessDeclaration(const protobuf::Descriptor* descriptor,
         friend class $2;
         friend class $0Proxy;
         friend class $0CProxy;
-        friend struct ::protos::internal::PrivateAccess;
+        friend struct ::hpb::internal::PrivateAccess;
         $1* msg_;
         upb_Arena* arena_;
       )cc",
@@ -206,7 +204,7 @@ void WriteModelPublicDeclaration(
           }
       )cc",
       ClassName(descriptor),
-      ::upb::generator::MessageInit(descriptor->full_name()),
+      ::upb::generator::MiniTableMessageVarName(descriptor->full_name()),
       MessageName(descriptor), QualifiedClassName(descriptor));
 
   WriteUsingAccessorsInHeader(descriptor, MessageClassType::kMessage, output);
@@ -217,7 +215,7 @@ void WriteModelPublicDeclaration(
     // for typetrait checking
     output("using ExtendableType = $0;\n", ClassName(descriptor));
   }
-  // Note: free function friends that are templates such as ::protos::Parse
+  // Note: free function friends that are templates such as ::hpb::Parse
   // require explicit <$2> type parameter in declaration to be able to compile
   // with gcc otherwise the compiler will fail with
   // "has not been declared within namespace" error. Even though there is a
@@ -226,7 +224,6 @@ void WriteModelPublicDeclaration(
   output(
       R"cc(
         static const upb_MiniTable* minitable();
-        using $0Access::GetInternalArena;
       )cc",
       ClassName(descriptor));
   output("\n");
@@ -237,25 +234,26 @@ void WriteModelPublicDeclaration(
         const upb_Message* msg() const { return UPB_UPCAST(msg_); }
         upb_Message* msg() { return UPB_UPCAST(msg_); }
 
+        upb_Arena* arena() const { return arena_; }
+
         $0(upb_Message* msg, upb_Arena* arena) : $0Access() {
           msg_ = ($1*)msg;
           arena_ = owned_arena_.ptr();
           upb_Arena_Fuse(arena_, arena);
         }
-        ::protos::Arena owned_arena_;
-        friend struct ::protos::internal::PrivateAccess;
+        ::hpb::Arena owned_arena_;
+        friend struct ::hpb::internal::PrivateAccess;
         friend Proxy;
         friend CProxy;
-        friend absl::StatusOr<$2>(::protos::Parse<$2>(absl::string_view bytes,
-                                                      int options));
-        friend absl::StatusOr<$2>(::protos::Parse<$2>(
+        friend absl::StatusOr<$2>(::hpb::Parse<$2>(absl::string_view bytes,
+                                                   int options));
+        friend absl::StatusOr<$2>(::hpb::Parse<$2>(
             absl::string_view bytes,
-            const ::protos::ExtensionRegistry& extension_registry,
-            int options));
-        friend upb_Arena* ::protos::internal::GetArena<$0>($0* message);
-        friend upb_Arena* ::protos::internal::GetArena<$0>(::protos::Ptr<$0> message);
-        friend $0(::protos::internal::MoveMessage<$0>(upb_Message* msg,
-                                                      upb_Arena* arena));
+            const ::hpb::ExtensionRegistry& extension_registry, int options));
+        friend upb_Arena* hpb::interop::upb::GetArena<$0>($0* message);
+        friend upb_Arena* hpb::interop::upb::GetArena<$0>(::hpb::Ptr<$0> message);
+        friend $0(hpb::interop::upb::MoveMessage<$0>(upb_Message* msg,
+                                                     upb_Arena* arena));
       )cc",
       ClassName(descriptor), MessageName(descriptor),
       QualifiedClassName(descriptor));
@@ -284,7 +282,6 @@ void WriteModelProxyDeclaration(const protobuf::Descriptor* descriptor,
             arena_ = m.arena_;
             return *this;
           }
-          using $0Access::GetInternalArena;
       )cc",
       ClassName(descriptor));
 
@@ -297,24 +294,25 @@ void WriteModelProxyDeclaration(const protobuf::Descriptor* descriptor,
         private:
         upb_Message* msg() const { return UPB_UPCAST(msg_); }
 
+        upb_Arena* arena() const { return arena_; }
+
         $0Proxy(upb_Message* msg, upb_Arena* arena)
             : internal::$0Access(($1*)msg, arena) {}
-        friend $0::Proxy(::protos::CreateMessage<$0>(::protos::Arena& arena));
-        friend $0::Proxy(::protos::internal::CreateMessageProxy<$0>(
-            upb_Message*, upb_Arena*));
-        friend struct ::protos::internal::PrivateAccess;
+        friend $0::Proxy(::hpb::CreateMessage<$0>(::hpb::Arena& arena));
+        friend $0::Proxy(hpb::interop::upb::MakeHandle<$0>(upb_Message*, upb_Arena*));
+        friend struct ::hpb::internal::PrivateAccess;
         friend class RepeatedFieldProxy;
         friend class $0CProxy;
         friend class $0Access;
-        friend class ::protos::Ptr<$0>;
-        friend class ::protos::Ptr<const $0>;
+        friend class ::hpb::Ptr<$0>;
+        friend class ::hpb::Ptr<const $0>;
         static const upb_MiniTable* minitable() { return $0::minitable(); }
-        friend const upb_MiniTable* ::protos::internal::GetMiniTable<$0Proxy>(
+        friend const upb_MiniTable* ::hpb::interop::upb::GetMiniTable<$0Proxy>(
             const $0Proxy* message);
-        friend const upb_MiniTable* ::protos::internal::GetMiniTable<$0Proxy>(
-            ::protos::Ptr<$0Proxy> message);
-        friend upb_Arena* ::protos::internal::GetArena<$2>($2* message);
-        friend upb_Arena* ::protos::internal::GetArena<$2>(::protos::Ptr<$2> message);
+        friend const upb_MiniTable* ::hpb::interop::upb::GetMiniTable<$0Proxy>(
+            ::hpb::Ptr<$0Proxy> message);
+        friend upb_Arena* hpb::interop::upb::GetArena<$2>($2* message);
+        friend upb_Arena* hpb::interop::upb::GetArena<$2>(::hpb::Ptr<$2> message);
         static void Rebind($0Proxy& lhs, const $0Proxy& rhs) {
           lhs.msg_ = rhs.msg_;
           lhs.arena_ = rhs.arena_;
@@ -335,9 +333,8 @@ void WriteModelCProxyDeclaration(const protobuf::Descriptor* descriptor,
          public:
           $0CProxy() = delete;
           $0CProxy(const $0* m)
-              : internal::$0Access(m->msg_, ::protos::internal::GetArena(m)) {}
+              : internal::$0Access(m->msg_, hpb::interop::upb::GetArena(m)) {}
           $0CProxy($0Proxy m);
-          using $0Access::GetInternalArena;
       )cc",
       ClassName(descriptor), MessageName(descriptor));
 
@@ -350,18 +347,19 @@ void WriteModelCProxyDeclaration(const protobuf::Descriptor* descriptor,
         private:
         using AsNonConst = $0Proxy;
         const upb_Message* msg() const { return UPB_UPCAST(msg_); }
+        upb_Arena* arena() const { return arena_; }
 
         $0CProxy(const upb_Message* msg, upb_Arena* arena)
             : internal::$0Access(($1*)msg, arena){};
-        friend struct ::protos::internal::PrivateAccess;
+        friend struct ::hpb::internal::PrivateAccess;
         friend class RepeatedFieldProxy;
-        friend class ::protos::Ptr<$0>;
-        friend class ::protos::Ptr<const $0>;
+        friend class ::hpb::Ptr<$0>;
+        friend class ::hpb::Ptr<const $0>;
         static const upb_MiniTable* minitable() { return $0::minitable(); }
-        friend const upb_MiniTable* ::protos::internal::GetMiniTable<$0CProxy>(
+        friend const upb_MiniTable* ::hpb::interop::upb::GetMiniTable<$0CProxy>(
             const $0CProxy* message);
-        friend const upb_MiniTable* ::protos::internal::GetMiniTable<$0CProxy>(
-            ::protos::Ptr<$0CProxy> message);
+        friend const upb_MiniTable* ::hpb::interop::upb::GetMiniTable<$0CProxy>(
+            ::hpb::Ptr<$0CProxy> message);
 
         static void Rebind($0CProxy& lhs, const $0CProxy& rhs) {
           lhs.msg_ = rhs.msg_;
@@ -375,7 +373,7 @@ void WriteModelCProxyDeclaration(const protobuf::Descriptor* descriptor,
 
 void WriteDefaultInstanceHeader(const protobuf::Descriptor* message,
                                 Output& output) {
-  output("  static ::protos::Ptr<const $0> default_instance();\n",
+  output("  static ::hpb::Ptr<const $0> default_instance();\n",
          ClassName(message));
 }
 
@@ -394,32 +392,32 @@ void WriteMessageImplementation(
           }
           $0::$0(const $0& from) : $0Access() {
             arena_ = owned_arena_.ptr();
-            msg_ = ($1*)::protos::internal::DeepClone(UPB_UPCAST(from.msg_), &$2, arena_);
+            msg_ = ($1*)::hpb::internal::DeepClone(UPB_UPCAST(from.msg_), &$2, arena_);
           }
           $0::$0(const CProxy& from) : $0Access() {
             arena_ = owned_arena_.ptr();
-            msg_ = ($1*)::protos::internal::DeepClone(
-                ::protos::internal::GetInternalMsg(&from), &$2, arena_);
+            msg_ = ($1*)::hpb::internal::DeepClone(
+                ::hpb::interop::upb::GetMessage(&from), &$2, arena_);
           }
           $0::$0(const Proxy& from) : $0(static_cast<const CProxy&>(from)) {}
           internal::$0CProxy::$0CProxy($0Proxy m) : $0Access() {
             arena_ = m.arena_;
-            msg_ = ($1*)::protos::internal::GetInternalMsg(&m);
+            msg_ = ($1*)::hpb::interop::upb::GetMessage(&m);
           }
           $0& $0::operator=(const $3& from) {
             arena_ = owned_arena_.ptr();
-            msg_ = ($1*)::protos::internal::DeepClone(UPB_UPCAST(from.msg_), &$2, arena_);
+            msg_ = ($1*)::hpb::internal::DeepClone(UPB_UPCAST(from.msg_), &$2, arena_);
             return *this;
           }
           $0& $0::operator=(const CProxy& from) {
             arena_ = owned_arena_.ptr();
-            msg_ = ($1*)::protos::internal::DeepClone(
-                ::protos::internal::GetInternalMsg(&from), &$2, arena_);
+            msg_ = ($1*)::hpb::internal::DeepClone(
+                ::hpb::interop::upb::GetMessage(&from), &$2, arena_);
             return *this;
           }
         )cc",
         ClassName(descriptor), MessageName(descriptor),
-        ::upb::generator::MessageInit(descriptor->full_name()),
+        ::upb::generator::MiniTableMessageVarName(descriptor->full_name()),
         QualifiedClassName(descriptor));
     output("\n");
     // Minitable
@@ -428,7 +426,7 @@ void WriteMessageImplementation(
           const upb_MiniTable* $0::minitable() { return &$1; }
         )cc",
         ClassName(descriptor),
-        ::upb::generator::MessageInit(descriptor->full_name()));
+        ::upb::generator::MiniTableMessageVarName(descriptor->full_name()));
     output("\n");
   }
 
@@ -451,8 +449,8 @@ void WriteMessageImplementation(
 
     output(
         R"cc(
-          ::protos::Ptr<const $0> $0::default_instance() {
-            return ::protos::internal::CreateMessage<$0>(
+          ::hpb::Ptr<const $0> $0::default_instance() {
+            return ::hpb::interop::upb::MakeCHandle<$0>(
                 (upb_Message *)_$0_default_instance_.msg,
                 _$0_default_instance_.arena);
           }
